@@ -28,40 +28,20 @@
 
 using namespace MessageComposer;
 
-class PluginEditorInitManagerInstancePrivate
-{
-public:
-    PluginEditorInitManagerInstancePrivate()
-        : pluginManager(new PluginEditorInitManager)
-    {
-    }
-
-    ~PluginEditorInitManagerInstancePrivate()
-    {
-        delete pluginManager;
-    }
-
-    PluginEditorInitManager *pluginManager;
-};
-
 class PluginEditorInitInfo
 {
 public:
     PluginEditorInitInfo()
-        : plugin(nullptr)
-        , isEnabled(true)
     {
     }
 
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PimCommon::PluginUtilData pluginData;
-    PluginEditorInit *plugin;
-    bool isEnabled;
+    PluginEditorInit *plugin = nullptr;
+    bool isEnabled = true;
 };
 
-Q_GLOBAL_STATIC(PluginEditorInitManagerInstancePrivate, sInstance)
-
 namespace {
 QString pluginVersion()
 {
@@ -194,7 +174,8 @@ PluginEditorInitManager::~PluginEditorInitManager()
 
 PluginEditorInitManager *PluginEditorInitManager::self()
 {
-    return sInstance->pluginManager;
+    static PluginEditorInitManager s_self;
+    return &s_self;
 }
 
 QVector<PluginEditorInit *> PluginEditorInitManager::pluginsList() const
