@@ -19,7 +19,7 @@
 
 #include "objecttreeviewersource.h"
 #include "csshelper.h"
-#include "bodypartformatterfactorysingleton.h"
+#include <MimeTreeParser/BodyPartFormatterFactory>
 
 #include <MimeTreeParser/BodyPartFormatter>
 #include "messagepartthemes/default/defaultrenderer.h"
@@ -55,8 +55,7 @@ bool MailViewerSource::showSignatureDetails() const
     return mViewer->mShowSignatureDetails;
 }
 
-void MailViewerSource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode,
-                                   const QList<MimeTreeParser::Util::HtmlMode> &availableModes)
+void MailViewerSource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode, const QList<MimeTreeParser::Util::HtmlMode> &availableModes)
 {
     mViewer->mColorBar->setAvailableModes(availableModes);
     mViewer->mColorBar->setMode(mode);
@@ -120,9 +119,9 @@ bool MailViewerSource::showExpandQuotesMark() const
     return MessageViewer::MessageViewerSettings::self()->showExpandQuotesMark();
 }
 
-const MimeTreeParser::BodyPartFormatterBaseFactory *MailViewerSource::bodyPartFormatterFactory()
+const MimeTreeParser::BodyPartFormatterFactory *MailViewerSource::bodyPartFormatterFactory()
 {
-    return bodyPartFormatterBaseFactoryInstance();
+    return MimeTreeParser::BodyPartFormatterFactory::instance();
 }
 
 bool MailViewerSource::isPrinting() const
@@ -130,10 +129,7 @@ bool MailViewerSource::isPrinting() const
     return mViewer->mPrinting;
 }
 
-MimeTreeParser::Interface::MessagePartRendererPtr MailViewerSource::messagePartTheme(
-    MimeTreeParser::Interface::MessagePart::Ptr msgPart)
+void MailViewerSource::render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *htmlWriter)
 {
-    return MimeTreeParser::Interface::MessagePartRenderer::Ptr(new DefaultRenderer(msgPart,
-                                                                                   mViewer->
-                                                                                   cssHelper()));
+    DefaultRenderer(msgPart, mViewer->cssHelper(), htmlWriter);
 }
