@@ -21,9 +21,9 @@
 
 #include "utils.h"
 
-#include "viewer/attachmentstrategy.h"
-#include "viewer/objecttreeparser.h"
-#include "viewer/messagepart.h"
+#include "attachmentstrategy.h"
+#include "objecttreeparser.h"
+#include "messagepart.h"
 
 #include <QGpgME/Protocol>
 
@@ -45,7 +45,7 @@ const Interface::BodyPartFormatter *ApplicationPkcs7MimeBodyPartFormatter::creat
     return self;
 }
 
-Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Interface::BodyPart &part) const
+MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Interface::BodyPart &part) const
 {
     KMime::Content *node = part.content();
 
@@ -58,6 +58,17 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         return MessagePart::Ptr();
     }
 
+    // we are also registered for octet-stream, in that case stop here if that's not a part for us
+    const auto mt = node->contentType()->mimeType();
+    const auto isCorrectMimeType = mt == QByteArrayLiteral("application/pkcs7-mime") || mt == QByteArrayLiteral("application/x-pkcs7-mime");
+    const auto hasCorrectName = mt == QByteArrayLiteral("application/octet-stream")
+                                && (node->contentType()->name().endsWith(QLatin1String("p7m"))
+                                    || node->contentType()->name().endsWith(QLatin1String("p7s"))
+                                    || node->contentType()->name().endsWith(QLatin1String("p7c")));
+    if (!isCorrectMimeType && !hasCorrectName) {
+        return {};
+    }
+
     const QString smimeType = node->contentType()->parameter(QStringLiteral("smime-type")).toLower();
 
     if (smimeType == QLatin1String("certs-only")) {
@@ -67,8 +78,8 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         return mp;
     }
 
-    bool isSigned      = (smimeType == QLatin1String("signed-data"));
-    bool isEncrypted   = (smimeType == QLatin1String("enveloped-data"));
+    bool isSigned = (smimeType == QLatin1String("signed-data"));
+    bool isEncrypted = (smimeType == QLatin1String("enveloped-data"));
 
     // Analyze "signTestNode" node to find/verify a signature.
     // If zero part.objectTreeParser() verification was successfully done after
@@ -87,8 +98,8 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         }
 
         auto _mp = EncryptedMessagePart::Ptr(new EncryptedMessagePart(part.objectTreeParser(),
-                                             node->decodedText(), smimeCrypto,
-                                             part.nodeHelper()->fromAsString(node), node));
+                                                                      node->decodedText(), smimeCrypto,
+                                                                      part.nodeHelper()->fromAsString(node), node));
         mp = _mp;
         _mp->setIsEncrypted(true);
         _mp->setDecryptMessage(part.source()->decryptMessage());
@@ -103,7 +114,6 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
                 isEncrypted = true;
                 part.nodeHelper()->setEncryptionState(node, KMMsgFullyEncrypted);
                 signTestNode = nullptr;
-
             } else {
                 // decryption failed, which could be because the part was encrypted but
                 // decryption failed, or because we didn't know if it was encrypted, tried,
@@ -138,21 +148,14 @@ Interface::MessagePart::Ptr ApplicationPkcs7MimeBodyPartFormatter::process(Inter
         const QTextCodec *aCodec(part.objectTreeParser()->codecFor(signTestNode));
         const QByteArray signaturetext = signTestNode->decodedContent();
         auto _mp = SignedMessagePart::Ptr(new SignedMessagePart(part.objectTreeParser(),
-                                          aCodec->toUnicode(signaturetext), smimeCrypto,
-                                          part.nodeHelper()->fromAsString(node), signTestNode));
+                                                                aCodec->toUnicode(signaturetext), smimeCrypto,
+                                                                part.nodeHelper()->fromAsString(node), signTestNode));
         mp = _mp;
-        //mp->setDecryptMessage(part.source()->decryptMessage());
-        PartMetaData *messagePart(mp->partMetaData());
-        if (smimeCrypto) {
-            _mp->startVerificationDetached(signaturetext, nullptr, QByteArray());
-        } else {
-            messagePart->auditLogError = GpgME::Error(GPG_ERR_NOT_IMPLEMENTED);
-        }
+        _mp->startVerificationDetached(signaturetext, nullptr, QByteArray());
 
         if (_mp->isSigned()) {
             if (!isSigned) {
                 qCDebug(MIMETREEPARSER_LOG) << "pkcs7 mime  -  signature found  -  opaque signed data !";
-                isSigned = true;
             }
 
             if (signTestNode != node) {
