@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -25,8 +25,7 @@
 #include <QStringList>
 #include "mimetreeparser_export.h"
 
-namespace MimeTreeParser
-{
+namespace MimeTreeParser {
 class AttachmentTemporaryFilesDirsPrivate;
 
 class MIMETREEPARSER_EXPORT AttachmentTemporaryFilesDirs : public QObject
@@ -52,7 +51,6 @@ private Q_SLOTS:
 private:
     AttachmentTemporaryFilesDirsPrivate *const d;
 };
-
 }
 
 #endif // ATTACHMENTTEMPORARYFILESDIRS_H
