@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,22 +21,27 @@
 #define CREATEPHISHINGURLDATABASEGUI_H
 
 #include <QWidget>
-class QTextEdit;
+#include "../createphishingurldatabasejob.h"
+class QPlainTextEdit;
+class QComboBox;
 class CreatePhisingUrlDataBaseGui : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CreatePhisingUrlDataBaseGui(QWidget *parent = Q_NULLPTR);
+    explicit CreatePhisingUrlDataBaseGui(QWidget *parent = nullptr);
     ~CreatePhisingUrlDataBaseGui();
 private Q_SLOTS:
     void slotResult(const QByteArray &data);
     void slotDownloadFullDatabase();
     void slotDebugJSon(const QByteArray &data);
     void slotDownloadPartialDatabase();
+    void slotSaveResultToDisk();
 private:
+    WebEngineViewer::CreatePhishingUrlDataBaseJob::ContraintsCompressionType compressionType();
     void clear();
-    QTextEdit *mResult;
-    QTextEdit *mJson;
+    QPlainTextEdit *mResult;
+    QPlainTextEdit *mJson;
+    QComboBox *mCompressionType;
 };
 
 #endif // CREATEPHISHINGURLDATABASEGUI_H
