@@ -24,8 +24,7 @@
 
 class QWebEngineView;
 
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class FindBarWebEngineViewPrivate;
 class WEBENGINEVIEWER_EXPORT FindBarWebEngineView : public FindBarBase
 {
@@ -35,14 +34,13 @@ public:
     ~FindBarWebEngineView();
 
 private:
-    void clearSelections() Q_DECL_OVERRIDE;
-    void searchText(bool backward, bool isAutoSearch) Q_DECL_OVERRIDE;
-    void updateSensitivity(bool sensitivity) Q_DECL_OVERRIDE;
+    void clearSelections() override;
+    void searchText(bool backward, bool isAutoSearch) override;
+    void updateSensitivity(bool sensitivity) override;
 
 private:
     FindBarWebEngineViewPrivate *const d;
 };
-
 }
 
 #endif
