@@ -23,8 +23,7 @@
 #include <QObject>
 #include "webengineviewer_export.h"
 class QWebEngineView;
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class NetworkPluginUrlInterceptorInterface;
 
 class WEBENGINEVIEWER_EXPORT NetworkPluginUrlInterceptor : public QObject
@@ -42,7 +41,7 @@ public:
     bool isEnabled() const;
 
 private:
-    bool mIsEnabled;
+    bool mIsEnabled = false;
 };
 }
 
